<script setup>
import { ref, computed, nextTick, onMounted } from "vue";
import { storeToRefs } from "pinia";
import { useUserStore } from "@/stores/user.js";

const userStore = useUserStore();
const { list, lastUname } = storeToRefs(userStore);
// console.log("list", list.value, "=============");
const $emit = defineEmits(["set-snid", "ok", "cancel-remember"]);

// 绑定的用户名
const username = ref("");

// 控制下拉列表的显示
const showDropdown = ref(false);

// 过滤后的用户名列表
const filteredUsers = computed(() => {
  return list.value.filter((user) => user.name.includes(username.value));
});

// 选择用户名并回写到输入框
function selectUser(user) {
  username.value = user.name;
  $emit("set-snid", user.snId);
  showDropdown.value = false; // 关闭下拉列表
}

// 处理输入框失去焦点的情况
function handleBlur() {
  setTimeout(() => {
    showDropdown.value = false;
  }, 200);
}

function test(params) {
  $emit("ok");
}

function filterUsers() {
  // 如果不是记住密码列表中的用户名 则取消记住密码
  if (!list.value.some((v) => v.name == username.value)) {
    $emit("cancel-remember");
  }
}
function initUser() {
  let _name = lastUname.value;
  username.value = _name;
  // 如果是记住密码列表中的用户名 则回写密码
  if (list.value.some((v) => v.name == _name)) {
    $emit("set-snid", list.value.find((v) => v.name == _name).snId);
  }
}
onMounted(() => {
  initUser();
});
defineExpose({ username });
</script>

<template>
  <div class="input-with-dropdown" @keydown.enter="test">
    <el-input
      class="input"
      v-model="username"
      placeholder="请输入用户名"
      @focus="showDropdown = true"
      @blur="handleBlur"
      @input="filterUsers"
    >
      <!-- @keyup.enter="onSubmit" -->
      <template #prefix>
        <el-icon class="el-input__icon"><User /></el-icon>
      </template>
    </el-input>
    <div v-if="showDropdown && filteredUsers.length > 0" class="dropdown">
      <ul>
        <li
          v-for="user in filteredUsers"
          :key="user.name"
          @click="selectUser(user)"
        >
          {{ user.name }}
        </li>
      </ul>
    </div>
  </div>
</template>

<style scoped>
.input-with-dropdown {
  position: relative;
  margin-bottom: 18px;
  z-index: 3;
}

.dropdown {
  position: absolute;
  top: 100%; /* 紧挨着输入框下方 */
  left: 0;
  right: 0;
  background-color: #ccc;
  border: 1px solid #000;
  border-top: none;
  z-index: 1;
}

.dropdown ul {
  list-style: none;
  padding: 0;
  margin: 0;
  color: #333;
  max-height: 220px;
  overflow-y: auto;
}

.dropdown li {
  padding: 6px 6px 6px 30px;
  cursor: pointer;
}

.dropdown li:hover {
  background-color: #aaa;
}
</style>
